<?php
/**
 * Nucleus functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * @package Nucleus
 * @since Nucleus 1.0
 */

/**
 * Nucleus only works in WordPress 4.4 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '4.4-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
}

$nucleus_theme = wp_get_theme();
define( 'NUCLEUS_VERSION', $nucleus_theme->get( 'Version' ) );
define( 'NUCLEUS_AUTHOR_URI', $nucleus_theme->get( 'AuthorURI' ) );
define( 'NUCLEUS_THEME_URI', $nucleus_theme->get( 'ThemeURI' ) );
define( 'NUCLEUS_TEXTDOMAIN', $nucleus_theme->get( 'TextDomain' ) );
define( 'NUCLEUS_TEMPLATE_PARTS', 'template-parts/' );

if ( ! function_exists( 'nucleus_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 *
	 * Create your own nucleus_setup() function to override in a child theme.
	 *
	 * @since Nucleus 1.0
	 */
	add_action( 'after_setup_theme', 'nucleus_setup' );
	function nucleus_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Nucleus, use a find and replace
		 * to change 'nucleus' to the name of your theme in all the template files
		 */
		load_theme_textdomain( 'nucleus', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		// Custom logo.
		add_theme_support( 'custom-logo', array(
			'width'       => '280',
			'height'      => '60',
			'flex-width'  => true,
			'flex-height' => true,
		) );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		 */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 1200, 9999 );
		add_image_size( 'nucleus-thumbnail-3x2', 720, 480, true );
		add_image_size( 'nucleus-thumbnail-1x1', 512, 512, true );

		// This theme uses wp_nav_menu().
		register_nav_menus( array(
			'primary'  => __( 'Primary Menu', 'nucleus' ),
			'social-1' => __( 'Social Links Menu (Top bar)', 'nucleus' ),
			'social-2' => __( 'Social Links Menu (Footer)', 'nucleus' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Custom background.
		add_theme_support( 'custom-background', array(
			'default-color' => 'ffffff',
		) );

		/*
		 * This theme styles the visual editor to resemble the theme style,
		 * specifically font, colors, icons, and column width.
		 */
		add_editor_style( array( 'css/editor-style.css', nucleus_fonts_url() ) );

		// Indicate widget sidebars can use selective refresh in the Customizer.
		add_theme_support( 'customize-selective-refresh-widgets' );
	}
endif; // nucleus_setup.

/**
 * Sets the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 *
 * @since Nucleus 1.0
 */
add_action( 'after_setup_theme', 'nucleus_content_width', 0 );
function nucleus_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'nucleus_content_width', 840 );
}

/**
 * Registers a widget area.
 *
 * @link https://developer.wordpress.org/reference/functions/register_sidebar/
 *
 * @since Nucleus 1.0
 */
add_action( 'widgets_init', 'nucleus_widgets_init' );
function nucleus_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'nucleus' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar.', 'nucleus' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span class="widget-title-icon"></span>',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Below entry title', 'nucleus' ),
		'id'            => 'sidebar-below-entry-title',
		'description'   => __( 'Appears below entry title in single posts.', 'nucleus' ),
		'before_widget' => '<section id="%1$s" class="sidebar-entry-content %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2>',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Below entry content', 'nucleus' ),
		'id'            => 'sidebar-below-entry-content',
		'description'   => __( 'Appears below entry content in single posts.', 'nucleus' ),
		'before_widget' => '<section id="%1$s" class="sidebar-entry-content %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2>',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Content Bottom 1', 'nucleus' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Appears at the bottom of the content on posts and pages.', 'nucleus' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Content Bottom 2', 'nucleus' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'Appears at the bottom of the content on posts and pages.', 'nucleus' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

}

if ( ! function_exists( 'nucleus_fonts_url' ) ) :
	/**
	 * Register Google fonts for Nucleus.
	 *
	 * Create your own nucleus_fonts_url() function to override in a child theme.
	 *
	 * @since Nucleus 1.0
	 *
	 * @return string Google fonts URL for the theme.
	 */
	function nucleus_fonts_url() {
		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin,latin-ext';
		$fuente    = esc_attr( get_theme_mod( 'nucleus_fonts', 'Open Sans' ) );

		$fonts[] = "$fuente:400,700,900,400italic,700italic,900italic";

		/* translators: If there are characters in your language that are not supported by Merriweather, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Merriweather font: on or off', 'nucleus' ) ) {
			$fonts[] = 'Merriweather:400,700,900,400italic,700italic,900italic';
		}

		/* translators: If there are characters in your language that are not supported by Montserrat, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Montserrat font: on or off', 'nucleus' ) ) {
			$fonts[] = 'Montserrat:400,700';
		}

		/* translators: If there are characters in your language that are not supported by Inconsolata, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Inconsolata font: on or off', 'nucleus' ) ) {
			$fonts[] = 'Inconsolata:400';
		}

		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $fonts ) ),
				'subset' => urlencode( $subsets ),
			), 'https://fonts.googleapis.com/css' );
		}

		return $fonts_url;
	}
endif;

/**
 * Add preconnect for Google Fonts.
 *
 * @since Nucleus 1.2.0
 *
 * @param array   $urls          URLs to print for resource hints.
 * @param string  $relation_type The relation type the URLs are printed.
 * @return array URLs to print for resource hints.
 */

add_filter( 'wp_resource_hints', 'nucleus_resource_hints', 10, 2 );
function nucleus_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'nucleus-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		if ( version_compare( $GLOBALS['wp_version'], '4.7-alpha', '>=' ) ) {
			$urls[] = array(
				'href' => 'https://fonts.gstatic.com',
				'crossorigin',
			);
		} else {
			$urls[] = 'https://fonts.gstatic.com';
		}
	}

	return $urls;
}

/**
 * Handles JavaScript detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 *
 * @since Nucleus 1.0
 */
add_action( 'wp_head', 'nucleus_javascript_detection', 0 );
function nucleus_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}

/**
 * Enqueues scripts and styles.
 *
 * @since Nucleus 1.0
 */
add_action( 'wp_enqueue_scripts', 'nucleus_scripts' );
function nucleus_scripts() {
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'nucleus-fonts', nucleus_fonts_url(), array(), null );

	// Add Genericons, used in the main stylesheet.
	wp_enqueue_style( 'genericons', get_template_directory_uri() . '/genericons/genericons.css', array(), '3.4.1' );

	// Add Dashicons.
	wp_enqueue_style( 'dashicons' );

	// Theme stylesheet.
	wp_enqueue_style( 'nucleus-style', get_stylesheet_uri(), '', NUCLEUS_VERSION );

	// Load the Internet Explorer specific stylesheet.
	wp_enqueue_style( 'nucleus-ie', get_template_directory_uri() . '/css/ie.css', array( 'nucleus-style' ), '20150930' );
	wp_style_add_data( 'nucleus-ie', 'conditional', 'lt IE 10' );

	// Load the Internet Explorer 8 specific stylesheet.
	wp_enqueue_style( 'nucleus-ie8', get_template_directory_uri() . '/css/ie8.css', array( 'nucleus-style' ), '20151230' );
	wp_style_add_data( 'nucleus-ie8', 'conditional', 'lt IE 9' );

	// Load the Internet Explorer 7 specific stylesheet.
	wp_enqueue_style( 'nucleus-ie7', get_template_directory_uri() . '/css/ie7.css', array( 'nucleus-style' ), '20150930' );
	wp_style_add_data( 'nucleus-ie7', 'conditional', 'lt IE 8' );

	// Load the html5 shiv.
	wp_enqueue_script( 'nucleus-html5', get_template_directory_uri() . '/js/html5.js', array(), '3.7.3' );
	wp_script_add_data( 'nucleus-html5', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'nucleus-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151112', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'nucleus-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20151104' );
	}

	wp_enqueue_script( 'nucleus-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '20151204', true );

	wp_localize_script( 'nucleus-script', 'screenReaderText', array(
		'expand'   => __( 'expand child menu', 'nucleus' ),
		'collapse' => __( 'collapse child menu', 'nucleus' ),
	) );

	// General scripts.
	wp_enqueue_script( 'nucleus-general-scripts', get_template_directory_uri() . '/js/nucleus-general-scripts.js', array( 'jquery' ), NUCLEUS_VERSION, true );
}

/**
 * Adds custom classes to the array of body classes.
 *
 * @since Nucleus 1.0
 *
 * @param array $classes Classes for the body element.
 * @return array (Maybe) filtered body classes.
 */
add_filter( 'body_class', 'nucleus_body_classes' );
function nucleus_body_classes( $classes ) {
	// Adds a class of custom-background-image to sites with a custom background image.
	if ( get_background_image() ) {
		$classes[] = 'custom-background-image';
	}

	// Adds a class of group-blog to sites with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of no-sidebar to sites without active sidebar.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}

/**
 * Converts a HEX value to RGB.
 *
 * @since Nucleus 1.0
 *
 * @param string $color The original color, in 3- or 6-digit hexadecimal form.
 * @return array Array containing RGB (red, green, and blue) values for the given
 *               HEX code, empty array otherwise.
 */
function nucleus_hex2rgb( $color ) {
	$color = trim( $color, '#' );

	if ( strlen( $color ) === 3 ) {
		$r = hexdec( substr( $color, 0, 1 ) . substr( $color, 0, 1 ) );
		$g = hexdec( substr( $color, 1, 1 ) . substr( $color, 1, 1 ) );
		$b = hexdec( substr( $color, 2, 1 ) . substr( $color, 2, 1 ) );
	} elseif ( strlen( $color ) === 6 ) {
		$r = hexdec( substr( $color, 0, 2 ) );
		$g = hexdec( substr( $color, 2, 2 ) );
		$b = hexdec( substr( $color, 4, 2 ) );
	} else {
		return array();
	}

	return array(
		'red'   => $r,
		'green' => $g,
		'blue'  => $b,
	);
}

/**
 * Add support for a custom header image.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */

require get_template_directory() . '/inc/nucleus-lite-customizer.php';
require get_template_directory() . '/inc/nucleus-lite-customization.php';

/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for content images
 *
 * @since Nucleus 1.0
 *
 * @param string $sizes A source size value for use in a 'sizes' attribute.
 * @param array  $size  Image size. Accepts an array of width and height
 *                      values in pixels (in that order).
 * @return string A source size value for use in a content image 'sizes' attribute.
 */
add_filter( 'wp_calculate_image_sizes', 'nucleus_content_image_sizes_attr', 10, 2 );
function nucleus_content_image_sizes_attr( $sizes, $size ) {
	$width = $size[0];

	if ( 840 <= $width ) {
		$sizes = '(max-width: 709px) 85vw, (max-width: 909px) 67vw, (max-width: 1362px) 62vw, 840px';
	}

	if ( 'page' === get_post_type() ) {
		if ( 840 > $width ) {
			$sizes = '(max-width: ' . $width . 'px) 85vw, ' . $width . 'px';
		}
	} else {
		if ( 840 > $width && 600 <= $width ) {
			$sizes = '(max-width: 709px) 85vw, (max-width: 909px) 67vw, (max-width: 984px) 61vw, (max-width: 1362px) 45vw, 600px';
		} elseif ( 600 > $width ) {
			$sizes = '(max-width: ' . $width . 'px) 85vw, ' . $width . 'px';
		}
	}

	return $sizes;
}

/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for post thumbnails
 *
 * @since Nucleus 1.0
 *
 * @param array $attr Attributes for the image markup.
 * @param int   $attachment Image attachment ID.
 * @param array $size Registered image size or flat array of height and width dimensions.
 * @return string A source size value for use in a post thumbnail 'sizes' attribute.
 */
add_filter( 'wp_get_attachment_image_attributes', 'nucleus_post_thumbnail_sizes_attr', 10, 3 );
function nucleus_post_thumbnail_sizes_attr( $attr, $attachment, $size ) {
	if ( 'post-thumbnail' === $size ) {
		is_active_sidebar( 'sidebar-1' ) && $attr['sizes'] = '(max-width: 709px) 85vw, (max-width: 909px) 67vw, (max-width: 984px) 60vw, (max-width: 1362px) 62vw, 840px';

		! is_active_sidebar( 'sidebar-1' ) && $attr['sizes'] = '(max-width: 709px) 85vw, (max-width: 909px) 67vw, (max-width: 1362px) 88vw, 1200px';
	}
	return $attr;
}

/**
 * Modifies tag cloud widget arguments to have all tags in the widget same font size.
 *
 * @since Nucleus 1.1
 *
 * @param array $args Arguments for tag cloud widget.
 * @return array A new modified arguments.
 */
add_filter( 'widget_tag_cloud_args', 'nucleus_widget_tag_cloud_args' );
function nucleus_widget_tag_cloud_args( $args ) {
	$args['largest']  = 1;
	$args['smallest'] = 1;
	$args['unit']     = 'em';
	return $args;
}

// Includes.
require_once get_template_directory() . '/inc/nucleus-help.php';
